# search-forecast


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

[![CI](https://github.com/redam94/search-forecast/actions/workflows/test.yaml/badge.svg)](https://github.com/redam94/search-forecast/actions/workflows/test.yaml)
[![Deploy to GitHub
Pages](https://github.com/redam94/search-forecast/actions/workflows/deploy.yaml/badge.svg)](https://github.com/redam94/search-forecast/actions/workflows/deploy.yaml)

This file will become your README and also the index of your
documentation.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install search_forecast in Development mode

``` sh
# make sure search_forecast package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to search_forecast
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/redam94/search-forecast):

``` sh
$ pip install git+https://github.com/redam94/search-forecast.git
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/redam94/search-forecast)’s
[pages](https://redam94.github.io/search-forecast/).
